(function (global, factory) {
    typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports) :
    typeof define === 'function' && define.amd ? define(['exports'], factory) :
    (global = global || self, factory(global.index = {}));
}(this, (function (exports) { 'use strict';

    var script = {
        name: 'CarouselDiagonal',
        props: {
            screens: {},
            sideWidth: { default: function (){ return 5 } },
            color: { default: function (){ return '#AA0F2F' } },
            style: {},
            textPrev: { default: function (){ return 'PREV' } },
        },
        data: function () {
            return {
                indexHover: null,
                indexClick: null,
            }
        },
        methods: {
            indexScreen: function indexScreen (screen) {
                if(!screen) { return }
                return this.screens.indexOf(screen)
            },
            refScreen: function refScreen (screen) {
                if(!screen) { return }
                return 'screen' + this.indexScreen(screen)
            },
            playVideo: function playVideo(screenPlay) {
                for (var i=0; i<this.screens.length; i++) {
                    var screenIth = this.screens[i];
                    if (this.refScreen(screenIth) === this.refScreen(screenPlay)) {
                        this.$refs[this.refScreen(screenIth)][0].play();
                    } else {
                        this.$refs[this.refScreen(screenIth)][0].pause();
                    }
                }
            },
            setHoverIndex: function setHoverIndex (screen) {
                this.indexHover = this.indexScreen(screen);
                this.playVideo(screen);
            },
            resetHoverIndex: function resetHoverIndex () {
                this.indexHover = null;
            },
            setClickIndex: function setClickIndex (screen) {
                this.indexClick = this.indexScreen(screen);
                this.playVideo(screen);
            },
            resetClickIndex: function resetClickIndex () {
                this.indexClick = null;
            },
            leftTitle: function leftTitle (screen) {
                var index = this.indexScreen(screen);

                // Check index
                if (index === 0) {
                    return this.widthScreen/4 + this.sideWidth/2
                } else if (index === this.screens.length-1) {
                    return 100 - this.widthScreen/4 - this.sideWidth/2
                } else {
                    return index * this.widthScreen + this.sideWidth
                }
            },
            zIndexScreen: function zIndexScreen (screen) {
                return this.indexScreen(screen) + 1
            },
            clipPathScreen: function clipPathScreen (screen) {
                var result;
                var index = this.indexScreen(screen);
                if (index === 0) {
                    return 'polygon(0% 0, 100% 0, 100% 100%, 0% 100%)'
                }
                var top = ((index-1) * this.widthScreen + this.sideWidth);
                var bottom = (index * this.widthScreen + this.sideWidth);

                if (this.indexClick !== null && this.indexClick >= 0) {
                    if (index === this.indexHover) {
                        top = 0;
                        bottom = 0;
                    } else if (index > this.indexHover) {
                        top = 100;
                        bottom = 100;
                    }

                }
                if (this.indexHover !== null && this.indexHover >= 0) {
                    if (index === this.indexHover) {
                        top -= this.sideWidth;
                        bottom -= this.sideWidth;
                    } else if (index === this.indexHover+1) {
                        top += this.sideWidth;
                        bottom += this.sideWidth;
                    }
                }
                // eslint-disable-next-line prefer-const
                result = 'polygon(' + top + '% 0, 100% 0, 100% 100%, ' + bottom +'% 100%)';
                return result
            },
            openLink: function openLink (screen) {
                window.open(screen.link, '_blank');
            }
        },
        computed: {
            widthScreen: function widthScreen () {
                var sideWidth = 5;
                if( this.sideWidth>0 && this.sideWidth<100 ) {
                    sideWidth = this.sideWidth;
                }
                return (100 - sideWidth*2) / (this.screens.length-1)
            }
        }
    };

    function normalizeComponent(template, style, script, scopeId, isFunctionalTemplate, moduleIdentifier /* server only */, shadowMode, createInjector, createInjectorSSR, createInjectorShadow) {
        if (typeof shadowMode !== 'boolean') {
            createInjectorSSR = createInjector;
            createInjector = shadowMode;
            shadowMode = false;
        }
        // Vue.extend constructor export interop.
        var options = typeof script === 'function' ? script.options : script;
        // render functions
        if (template && template.render) {
            options.render = template.render;
            options.staticRenderFns = template.staticRenderFns;
            options._compiled = true;
            // functional template
            if (isFunctionalTemplate) {
                options.functional = true;
            }
        }
        // scopedId
        if (scopeId) {
            options._scopeId = scopeId;
        }
        var hook;
        if (moduleIdentifier) {
            // server build
            hook = function (context) {
                // 2.3 injection
                context =
                    context || // cached call
                        (this.$vnode && this.$vnode.ssrContext) || // stateful
                        (this.parent && this.parent.$vnode && this.parent.$vnode.ssrContext); // functional
                // 2.2 with runInNewContext: true
                if (!context && typeof __VUE_SSR_CONTEXT__ !== 'undefined') {
                    context = __VUE_SSR_CONTEXT__;
                }
                // inject component styles
                if (style) {
                    style.call(this, createInjectorSSR(context));
                }
                // register component module identifier for async chunk inference
                if (context && context._registeredComponents) {
                    context._registeredComponents.add(moduleIdentifier);
                }
            };
            // used by ssr in case component is cached and beforeCreate
            // never gets called
            options._ssrRegister = hook;
        }
        else if (style) {
            hook = shadowMode
                ? function (context) {
                    style.call(this, createInjectorShadow(context, this.$root.$options.shadowRoot));
                }
                : function (context) {
                    style.call(this, createInjector(context));
                };
        }
        if (hook) {
            if (options.functional) {
                // register for functional component in vue file
                var originalRender = options.render;
                options.render = function renderWithStyleInjection(h, context) {
                    hook.call(context);
                    return originalRender(h, context);
                };
            }
            else {
                // inject component registration as beforeCreate hook
                var existing = options.beforeCreate;
                options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
            }
        }
        return script;
    }

    var isOldIE = typeof navigator !== 'undefined' &&
        /msie [6-9]\\b/.test(navigator.userAgent.toLowerCase());
    function createInjector(context) {
        return function (id, style) { return addStyle(id, style); };
    }
    var HEAD;
    var styles = {};
    function addStyle(id, css) {
        var group = isOldIE ? css.media || 'default' : id;
        var style = styles[group] || (styles[group] = { ids: new Set(), styles: [] });
        if (!style.ids.has(id)) {
            style.ids.add(id);
            var code = css.source;
            if (css.map) {
                // https://developer.chrome.com/devtools/docs/javascript-debugging
                // this makes source maps inside style tags work properly in Chrome
                code += '\n/*# sourceURL=' + css.map.sources[0] + ' */';
                // http://stackoverflow.com/a/26603875
                code +=
                    '\n/*# sourceMappingURL=data:application/json;base64,' +
                        btoa(unescape(encodeURIComponent(JSON.stringify(css.map)))) +
                        ' */';
            }
            if (!style.element) {
                style.element = document.createElement('style');
                style.element.type = 'text/css';
                if (css.media)
                    { style.element.setAttribute('media', css.media); }
                if (HEAD === undefined) {
                    HEAD = document.head || document.getElementsByTagName('head')[0];
                }
                HEAD.appendChild(style.element);
            }
            if ('styleSheet' in style.element) {
                style.styles.push(code);
                style.element.styleSheet.cssText = style.styles
                    .filter(Boolean)
                    .join('\n');
            }
            else {
                var index = style.ids.size - 1;
                var textNode = document.createTextNode(code);
                var nodes = style.element.childNodes;
                if (nodes[index])
                    { style.element.removeChild(nodes[index]); }
                if (nodes.length)
                    { style.element.insertBefore(textNode, nodes[index]); }
                else
                    { style.element.appendChild(textNode); }
            }
        }
    }

    /* script */
    var __vue_script__ = script;

    /* template */
    var __vue_render__ = function() {
      var _vm = this;
      var _h = _vm.$createElement;
      var _c = _vm._self._c || _h;
      return _c(
        "div",
        {
          class: { clicked: _vm.indexClick !== null },
          attrs: { id: "CarouselDiagonal" },
          on: { mouseleave: _vm.resetHoverIndex }
        },
        [
          _vm._l(_vm.screens, function(screen, index) {
            return _c(
              "div",
              {
                key: index,
                staticClass: "screen",
                style: {
                  "clip-path": _vm.clipPathScreen(screen),
                  "z-index": _vm.zIndexScreen(screen)
                },
                on: {
                  mouseover: function($event) {
                    return _vm.setHoverIndex(screen)
                  },
                  click: function($event) {
                    return _vm.setClickIndex(screen)
                  }
                }
              },
              [
                screen.video
                  ? _c(
                      "video",
                      {
                        ref: _vm.refScreen(screen),
                        refInFor: true,
                        staticClass: "b-img",
                        attrs: { loop: "", muted: "" },
                        domProps: { muted: true }
                      },
                      [
                        _c("source", {
                          attrs: { src: screen.video, type: "video/mp4" }
                        })
                      ]
                    )
                  : _vm._e(),
                _vm._v(" "),
                screen.image
                  ? _c("img", {
                      ref: _vm.refScreen(screen),
                      refInFor: true,
                      staticClass: "b-img",
                      attrs: { src: screen.image }
                    })
                  : _vm._e(),
                _vm._v(" "),
                _c(
                  "div",
                  {
                    staticClass: "title",
                    style: {
                      left: _vm.leftTitle(screen) + "%"
                    }
                  },
                  [
                    _c("div", { staticClass: "title1" }, [
                      _vm._v(_vm._s(screen.subtitle))
                    ]),
                    _c("br"),
                    _vm._v(" "),
                    _c("div", { staticClass: "title2" }, [
                      _vm._v(_vm._s(screen.title))
                    ])
                  ]
                )
              ]
            )
          }),
          _vm._v(" "),
          _c("transition", { attrs: { name: "fade" } }, [
            _vm.indexClick !== null
              ? _c(
                  "button",
                  { staticClass: "reset", on: { click: _vm.resetClickIndex } },
                  [
                    _c(
                      "svg",
                      {
                        attrs: {
                          width: "11px",
                          height: "20px",
                          viewBox: "0 0 11 20",
                          version: "1.1",
                          xmlns: "http://www.w3.org/2000/svg",
                          "xmlns:xlink": "http://www.w3.org/1999/xlink"
                        }
                      },
                      [
                        _c(
                          "g",
                          {
                            attrs: {
                              id: "Icons",
                              stroke: "none",
                              "stroke-width": "1",
                              fill: "none",
                              "fill-rule": "evenodd"
                            }
                          },
                          [
                            _c(
                              "g",
                              {
                                attrs: {
                                  id: "Rounded",
                                  transform: "translate(-548.000000, -3434.000000)"
                                }
                              },
                              [
                                _c(
                                  "g",
                                  {
                                    attrs: {
                                      id: "Navigation",
                                      transform:
                                        "translate(100.000000, 3378.000000)"
                                    }
                                  },
                                  [
                                    _c(
                                      "g",
                                      {
                                        attrs: {
                                          id:
                                            "-Round-/-Navigation-/-arrow_back_ios",
                                          transform:
                                            "translate(442.000000, 54.000000)"
                                        }
                                      },
                                      [
                                        _c("g", [
                                          _c("polygon", {
                                            attrs: {
                                              id: "Path",
                                              opacity: "0.87",
                                              points: "0 0 24 0 24 24 0 24"
                                            }
                                          }),
                                          _vm._v(" "),
                                          _c("path", {
                                            attrs: {
                                              d:
                                                "M16.62,2.99 C16.13,2.5 15.34,2.5 14.85,2.99 L6.54,11.3 C6.15,11.69 6.15,12.32 6.54,12.71 L14.85,21.02 C15.34,21.51 16.13,21.51 16.62,21.02 C17.11,20.53 17.11,19.74 16.62,19.25 L9.38,12 L16.63,4.75 C17.11,4.27 17.11,3.47 16.62,2.99 Z",
                                              id: "🔹-Icon-Color",
                                              fill: "#FFFFFF"
                                            }
                                          })
                                        ])
                                      ]
                                    )
                                  ]
                                )
                              ]
                            )
                          ]
                        )
                      ]
                    ),
                    _vm._v(" "),
                    _c("span", [_vm._v(_vm._s(_vm.textPrev))])
                  ]
                )
              : _vm._e()
          ])
        ],
        2
      )
    };
    var __vue_staticRenderFns__ = [];
    __vue_render__._withStripped = true;

      /* style */
      var __vue_inject_styles__ = function (inject) {
        if (!inject) { return }
        inject("data-v-4228de5a_0", { source: "#CarouselDiagonal {\n  position: relative;\n  display: block;\n  float: left;\n}\n#CarouselDiagonal .screen {\n  position: absolute;\n  top: 0;\n  left: 0;\n  display: block;\n  float: left;\n  width: 100%;\n  height: 100%;\n  overflow: hidden;\n  transition: all 1s;\n}\n#CarouselDiagonal .screen .title {\n  position: absolute;\n  top: 50%;\n  z-index: 6;\n  display: inline-block;\n  color: white;\n  transition: all 2s;\n  transform: translateX(-50%) translateY(-50%);\n}\n#CarouselDiagonal .screen .title .title1 {\n  font-size: 27px;\n  font-weight: 600;\n  text-shadow: 0 4px 8px rgba(0, 0, 0, 0.25);\n  float: left;\n}\n#CarouselDiagonal .screen .title .title2 {\n  font-size: 36px;\n  font-weight: 900;\n  text-shadow: 0 4px 8px rgba(0, 0, 0, 0.25);\n  float: left;\n}\n#CarouselDiagonal.clicked .title {\n  top: 50% !important;\n  left: 50% !important;\n  opacity: 0;\n  transform: translateX(-50%) translateY(-50%) !important;\n}\n#CarouselDiagonal .reset {\n  position: absolute;\n  bottom: 5%;\n  left: 5%;\n  z-index: 6;\n  font-size: 18px;\n  color: white;\n  background: none;\n  line-height: 20px;\n  padding: 10px;\n}\n#CarouselDiagonal .reset * {\n  float: left;\n}\n#CarouselDiagonal .reset span {\n  line-height: 20px;\n  vertical-align: middle;\n  margin-left: 12px;\n}\n#CarouselDiagonal .fade-enter-active, #CarouselDiagonal .fade-leave-active {\n  transition: opacity 1s;\n  opacity: 100;\n}\n#CarouselDiagonal .fade-enter, #CarouselDiagonal .fade-leave-to {\n  opacity: 0;\n}\n#CarouselDiagonal .b-img {\n  width: 100%;\n  height: 100%;\n  background-size: cover;\n  background-position: center center;\n  object-fit: cover;\n}\n#CarouselDiagonal button, #CarouselDiagonal button:focus {\n  border: none;\n  outline: none;\n  background: none;\n  cursor: pointer;\n}\n#CarouselDiagonal video::-webkit-media-controls-panel {\n  display: none !important;\n  -webkit-appearance: none;\n}\n#CarouselDiagonal video::-webkit-media-controls-play-button {\n  display: none !important;\n  -webkit-appearance: none;\n}\n#CarouselDiagonal video::-webkit-media-controls-start-playback-button {\n  display: none !important;\n  -webkit-appearance: none;\n}\n\n/*# sourceMappingURL=CarouselDiagonal.vue.map */", map: {"version":3,"sources":["/Users/idist/Desktop/git/library/vue-carousel-diagonal/src/components/CarouselDiagonal.vue","CarouselDiagonal.vue"],"names":[],"mappings":"AA6JA;EACA,kBAAA;EACA,cAAA;EACA,WAAA;AC5JA;AD6JA;EACA,kBAAA;EACA,MAAA;EACA,OAAA;EACA,cAAA;EACA,WAAA;EACA,WAAA;EACA,YAAA;EACA,gBAAA;EACA,kBAAA;AC3JA;AD4JA;EACA,kBAAA;EACA,QAAA;EACA,UAAA;EACA,qBAAA;EACA,YAAA;EACA,kBAAA;EACA,4CAAA;AC1JA;AD2JA;EACA,eAAA;EACA,gBAAA;EACA,0CAAA;EACA,WAAA;ACzJA;AD2JA;EACA,eAAA;EACA,gBAAA;EACA,0CAAA;EACA,WAAA;ACzJA;AD8JA;EACA,mBAAA;EACA,oBAAA;EACA,UAAA;EACA,uDAAA;AC5JA;AD+JA;EACA,kBAAA;EACA,UAAA;EACA,QAAA;EACA,UAAA;EACA,eAAA;EACA,YAAA;EACA,gBAAA;EACA,iBAAA;EACA,aAAA;AC7JA;AD8JA;EAAA,WAAA;AC3JA;AD4JA;EACA,iBAAA;EACA,sBAAA;EACA,iBAAA;AC1JA;AD8JA;EACA,sBAAA;EACA,YAAA;AC5JA;AD8JA;EACA,UAAA;AC5JA;AD8JA;EACA,WAAA;EACA,YAAA;EACA,sBAAA;EACA,kCAAA;EACA,iBAAA;AC5JA;AD8JA;EACA,YAAA;EACA,aAAA;EACA,gBAAA;EACA,eAAA;AC5JA;AD+JA;EAAA,wBAAA;EAAA,wBAAA;AC3JA;AD4JA;EAAA,wBAAA;EAAA,wBAAA;ACxJA;ADyJA;EAAA,wBAAA;EAAA,wBAAA;ACrJA;;AAEA,+CAA+C","file":"CarouselDiagonal.vue","sourcesContent":["<script>\n    export default {\n        name: 'CarouselDiagonal',\n        props: {\n            screens: {},\n            sideWidth: { default: ()=> { return 5 } },\n            color: { default: ()=> { return '#AA0F2F' } },\n            style: {},\n            textPrev: { default: ()=> { return 'PREV' } },\n        },\n        data: function () {\n            return {\n                indexHover: null,\n                indexClick: null,\n            }\n        },\n        methods: {\n            indexScreen (screen) {\n                if(!screen) { return }\n                return this.screens.indexOf(screen)\n            },\n            refScreen (screen) {\n                if(!screen) { return }\n                return 'screen' + this.indexScreen(screen)\n            },\n            playVideo(screenPlay) {\n                for (let i=0; i<this.screens.length; i++) {\n                    const screenIth = this.screens[i]\n                    if (this.refScreen(screenIth) === this.refScreen(screenPlay)) {\n                        this.$refs[this.refScreen(screenIth)][0].play()\n                    } else {\n                        this.$refs[this.refScreen(screenIth)][0].pause()\n                    }\n                }\n            },\n            setHoverIndex (screen) {\n                this.indexHover = this.indexScreen(screen)\n                this.playVideo(screen)\n            },\n            resetHoverIndex () {\n                this.indexHover = null\n            },\n            setClickIndex (screen) {\n                this.indexClick = this.indexScreen(screen)\n                this.playVideo(screen)\n            },\n            resetClickIndex () {\n                this.indexClick = null\n            },\n            leftTitle (screen) {\n                const index = this.indexScreen(screen)\n\n                // Check index\n                if (index === 0) {\n                    return this.widthScreen/4 + this.sideWidth/2\n                } else if (index === this.screens.length-1) {\n                    return 100 - this.widthScreen/4 - this.sideWidth/2\n                } else {\n                    return index * this.widthScreen + this.sideWidth\n                }\n            },\n            zIndexScreen (screen) {\n                return this.indexScreen(screen) + 1\n            },\n            clipPathScreen (screen) {\n                let result\n                const index = this.indexScreen(screen)\n                if (index === 0) {\n                    return 'polygon(0% 0, 100% 0, 100% 100%, 0% 100%)'\n                }\n                let top = ((index-1) * this.widthScreen + this.sideWidth)\n                let bottom = (index * this.widthScreen + this.sideWidth)\n\n                if (this.indexClick !== null && this.indexClick >= 0) {\n                    if (index === this.indexHover) {\n                        top = 0\n                        bottom = 0\n                    } else if (index > this.indexHover) {\n                        top = 100\n                        bottom = 100\n                    }\n\n                }\n                if (this.indexHover !== null && this.indexHover >= 0) {\n                    if (index === this.indexHover) {\n                        top -= this.sideWidth\n                        bottom -= this.sideWidth\n                    } else if (index === this.indexHover+1) {\n                        top += this.sideWidth\n                        bottom += this.sideWidth\n                    }\n                }\n                // eslint-disable-next-line prefer-const\n                result = 'polygon(' + top + '% 0, 100% 0, 100% 100%, ' + bottom +'% 100%)'\n                return result\n            },\n            openLink (screen) {\n                window.open(screen.link, '_blank')\n            }\n        },\n        computed: {\n            widthScreen () {\n                let sideWidth = 5\n                if( this.sideWidth>0 && this.sideWidth<100 ) {\n                    sideWidth = this.sideWidth\n                }\n                return (100 - sideWidth*2) / (this.screens.length-1)\n            }\n        }\n    }\n</script>\n\n<template>\n    <div id=\"CarouselDiagonal\" :class=\"{ 'clicked': indexClick !== null }\" @mouseleave=\"resetHoverIndex\">\n        <div v-for=\"(screen, index) in screens\"\n             :key=\"index\" class=\"screen\"\n             @mouseover=\"setHoverIndex(screen)\"\n             @click=\"setClickIndex(screen)\"\n             :style=\"{\n                'clip-path': clipPathScreen(screen),\n                'z-index': zIndexScreen(screen),\n            }\">\n            <!--Video-->\n            <video class=\"b-img\" v-if=\"screen.video\" :ref=\"refScreen(screen)\" loop muted><source :src=\"screen.video\" type=\"video/mp4\"></video>\n            <img class=\"b-img\" v-if=\"screen.image\" :ref=\"refScreen(screen)\" :src=\"screen.image\"/>\n\n            <!--Title-->\n            <div class=\"title\" :style=\"{\n              'left': leftTitle(screen) + '%',\n            }\">\n                <div class=\"title1\">{{screen.subtitle}}</div><br/>\n                <div class=\"title2\">{{screen.title}}</div>\n            </div>\n        </div>\n        <transition name=\"fade\">\n            <button class=\"reset\" @click=\"resetClickIndex\" v-if=\"indexClick !== null\">\n                <svg width=\"11px\" height=\"20px\" viewBox=\"0 0 11 20\" version=\"1.1\" xmlns=\"http://www.w3.org/2000/svg\" xmlns:xlink=\"http://www.w3.org/1999/xlink\">\n                    <g id=\"Icons\" stroke=\"none\" stroke-width=\"1\" fill=\"none\" fill-rule=\"evenodd\">\n                        <g id=\"Rounded\" transform=\"translate(-548.000000, -3434.000000)\">\n                            <g id=\"Navigation\" transform=\"translate(100.000000, 3378.000000)\">\n                                <g id=\"-Round-/-Navigation-/-arrow_back_ios\" transform=\"translate(442.000000, 54.000000)\">\n                                    <g>\n                                        <polygon id=\"Path\" opacity=\"0.87\" points=\"0 0 24 0 24 24 0 24\"></polygon>\n                                        <path d=\"M16.62,2.99 C16.13,2.5 15.34,2.5 14.85,2.99 L6.54,11.3 C6.15,11.69 6.15,12.32 6.54,12.71 L14.85,21.02 C15.34,21.51 16.13,21.51 16.62,21.02 C17.11,20.53 17.11,19.74 16.62,19.25 L9.38,12 L16.63,4.75 C17.11,4.27 17.11,3.47 16.62,2.99 Z\" id=\"🔹-Icon-Color\" fill=\"#FFFFFF\"></path>\n                                    </g>\n                                </g>\n                            </g>\n                        </g>\n                    </g>\n                </svg>\n                <span>{{textPrev}}</span>\n            </button>\n        </transition>\n    </div>\n</template>\n\n<style lang=\"scss\">\n    #CarouselDiagonal {\n        position: relative;\n        display: block;\n        float: left;\n        .screen {\n            position: absolute;\n            top: 0;\n            left: 0;\n            display: block;\n            float: left;\n            width: 100%;\n            height: 100%;\n            overflow: hidden;\n            transition: all 1s;\n            .title {\n                position: absolute;\n                top: 50%;\n                z-index: 6;\n                display: inline-block;\n                color: white;\n                transition: all 2s;\n                transform: translateX(-50%) translateY(-50%);\n                .title1 {\n                    font-size: 27px;\n                    font-weight: 600;\n                    text-shadow: 0 4px 8px rgba(0, 0, 0, 0.25);\n                    float: left;\n                }\n                .title2 {\n                    font-size: 36px;\n                    font-weight: 900;\n                    text-shadow: 0 4px 8px rgba(0, 0, 0, 0.25);\n                    float: left;\n                }\n            }\n        }\n        &.clicked {\n            .title {\n                top:50% !important;\n                left: 50% !important;\n                opacity: 0;\n                transform: translateX(-50%) translateY(-50%) !important;\n            }\n        }\n        .reset {\n            position: absolute;\n            bottom: 5%;\n            left: 5%;\n            z-index: 6;\n            font-size: 18px;\n            color: white;\n            background: none;\n            line-height: 20px;\n            padding: 10px;\n            * { float: left; }\n            span {\n                line-height: 20px;\n                vertical-align: middle;\n                margin-left: 12px;\n            }\n        }\n\n        .fade-enter-active, .fade-leave-active {\n            transition: opacity 1s;\n            opacity: 100;\n        }\n        .fade-enter, .fade-leave-to /* .fade-leave-active below version 2.1.8 */ {\n            opacity: 0;\n        }\n        .b-img {\n            width: 100%;\n            height: 100%;\n            background-size: cover;\n            background-position: center center;\n            object-fit: cover;\n        }\n        button, button:focus {\n            border:none;\n            outline: none;\n            background: none;\n            cursor: pointer;\n        }\n\n        video::-webkit-media-controls-panel { display: none!important; -webkit-appearance: none; }\n        video::-webkit-media-controls-play-button { display: none!important; -webkit-appearance: none; }\n        video::-webkit-media-controls-start-playback-button { display: none!important; -webkit-appearance: none; }\n\n    }\n</style>","#CarouselDiagonal {\n  position: relative;\n  display: block;\n  float: left;\n}\n#CarouselDiagonal .screen {\n  position: absolute;\n  top: 0;\n  left: 0;\n  display: block;\n  float: left;\n  width: 100%;\n  height: 100%;\n  overflow: hidden;\n  transition: all 1s;\n}\n#CarouselDiagonal .screen .title {\n  position: absolute;\n  top: 50%;\n  z-index: 6;\n  display: inline-block;\n  color: white;\n  transition: all 2s;\n  transform: translateX(-50%) translateY(-50%);\n}\n#CarouselDiagonal .screen .title .title1 {\n  font-size: 27px;\n  font-weight: 600;\n  text-shadow: 0 4px 8px rgba(0, 0, 0, 0.25);\n  float: left;\n}\n#CarouselDiagonal .screen .title .title2 {\n  font-size: 36px;\n  font-weight: 900;\n  text-shadow: 0 4px 8px rgba(0, 0, 0, 0.25);\n  float: left;\n}\n#CarouselDiagonal.clicked .title {\n  top: 50% !important;\n  left: 50% !important;\n  opacity: 0;\n  transform: translateX(-50%) translateY(-50%) !important;\n}\n#CarouselDiagonal .reset {\n  position: absolute;\n  bottom: 5%;\n  left: 5%;\n  z-index: 6;\n  font-size: 18px;\n  color: white;\n  background: none;\n  line-height: 20px;\n  padding: 10px;\n}\n#CarouselDiagonal .reset * {\n  float: left;\n}\n#CarouselDiagonal .reset span {\n  line-height: 20px;\n  vertical-align: middle;\n  margin-left: 12px;\n}\n#CarouselDiagonal .fade-enter-active, #CarouselDiagonal .fade-leave-active {\n  transition: opacity 1s;\n  opacity: 100;\n}\n#CarouselDiagonal .fade-enter, #CarouselDiagonal .fade-leave-to {\n  opacity: 0;\n}\n#CarouselDiagonal .b-img {\n  width: 100%;\n  height: 100%;\n  background-size: cover;\n  background-position: center center;\n  object-fit: cover;\n}\n#CarouselDiagonal button, #CarouselDiagonal button:focus {\n  border: none;\n  outline: none;\n  background: none;\n  cursor: pointer;\n}\n#CarouselDiagonal video::-webkit-media-controls-panel {\n  display: none !important;\n  -webkit-appearance: none;\n}\n#CarouselDiagonal video::-webkit-media-controls-play-button {\n  display: none !important;\n  -webkit-appearance: none;\n}\n#CarouselDiagonal video::-webkit-media-controls-start-playback-button {\n  display: none !important;\n  -webkit-appearance: none;\n}\n\n/*# sourceMappingURL=CarouselDiagonal.vue.map */"]}, media: undefined });

      };
      /* scoped */
      var __vue_scope_id__ = undefined;
      /* module identifier */
      var __vue_module_identifier__ = undefined;
      /* functional template */
      var __vue_is_functional_template__ = false;
      /* style inject SSR */
      
      /* style inject shadow dom */
      

      
      var __vue_component__ = /*#__PURE__*/normalizeComponent(
        { render: __vue_render__, staticRenderFns: __vue_staticRenderFns__ },
        __vue_inject_styles__,
        __vue_script__,
        __vue_scope_id__,
        __vue_is_functional_template__,
        __vue_module_identifier__,
        false,
        createInjector,
        undefined,
        undefined
      );

    // Import vue component

    // Declare install function executed by Vue.use()
    function install(Vue) {
        if (install.installed) { return; }
        install.installed = true;
        Vue.component('DiagnoalScreen', __vue_component__);
    }

    // Create module definition for Vue.use()
    var plugin = {
        install: install,
    };

    // Auto-install when vue is found (eg. in browser via <script> tag)
    var GlobalVue = null;
    if (typeof window !== 'undefined') {
        GlobalVue = window.Vue;
    } else if (typeof global !== 'undefined') {
        GlobalVue = global.Vue;
    }
    if (GlobalVue) {
        GlobalVue.use(plugin);
    }

    exports.default = __vue_component__;
    exports.install = install;

    Object.defineProperty(exports, '__esModule', { value: true });

})));
